String (Str) Functions
-----------------------

A string manipulation module.

.. dropdown:: Str.ils sourcecode

    .. literalinclude:: ../../_static/src/data_types/Str.ils
       :language: scheme
       :linenos:
